@@ -4,8 +4,8 @@
 
 ;; Author: Alvaro Ramirez https://xenodium.com
 ;; URL: https://github.com/xenodium/shell-maker
-;; Package-Version: 20260104.1718
-;; Package-Revision: 53742d44b48a
+;; Package-Version: 20260116.1019
+;; Package-Revision: 6eafe72de916
 ;; Package-Requires: ((emacs "27.1"))
 
 ;; This package is free software; you can redistribute it and/or modify
@@ -33,7 +33,7 @@
 
 ;;; Code:
 
-(defconst shell-maker-version "0.84.5")
+(defconst shell-maker-version "0.84.8")
 
 (require 'comint)
 (require 'goto-addr)
@@ -161,6 +161,7 @@ or an absolute path like \"/usr/local/bin/curl\"."
   :parent comint-mode-map
   :doc "Base keymap for `shell-maker' based modes."
   "S-<return>" #'newline
+  "<remap> <rename-buffer>" #'shell-maker-rename-buffer
   "<remap> <save-buffer>" #'shell-maker-save-session-transcript
   "C-M-h" #'shell-maker-mark-output)
 
@@ -208,6 +209,7 @@ Set MODE-LINE-NAME to override the mode line name."
         `(define-derived-mode ,(shell-maker-major-mode config) comint-mode
            ,(or mode-line-name (shell-maker-config-name config))
            ,(format "Major mode for %s shell." (shell-maker-config-name config))
+           (keymap-set shell-maker-mode-map "<remap> <comint-delchar-or-maybe-eof>" #'delete-char)
            (keymap-set shell-maker-mode-map "<remap> <comint-send-input>" #'shell-maker-submit)
            (keymap-set shell-maker-mode-map "<remap> <comint-interrupt-subjob>" #'shell-maker-interrupt)
            (keymap-set shell-maker-mode-map "<remap> <comint-history-isearch-backward-regexp>" #'shell-maker-search-history))))
